<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>སྡེར་མའི་མཚོན་རྟགས་ལ་གནོན་རྒྱུ།
ཡང་ན་བརྙན་ཕབ་ཀྱི་མྱུར་མཐེབ་མནན་ནས་བརྙན་ཕབ་མཚམས་འཇོག་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>བརྙན་ལེན་བཞིན་ཡོད་པས་སྐོར་བ་མ་རྒྱག</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>ཉར་མི་ཐུབ་པས། མིག་སྔའི་སྤྱོད་མཁན་གྱི་དཀར་ཆག་འོག་ཏུ་ཉར་རོགས།</translation>
    </message>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>བརྙན་བཤུས་ཚར་བ།</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>ཁུལ་ཁོངས་འདེམས་པ།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>སྣང་མེད།</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>དྲས་སྦྱར་པང་།</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>བརྙན་ཕབ་ཡིག་ཆ་ཉར་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>ཕབ་བཟོ་བྱེད་པའི་བརྒྱུད་རིམ་ནང་སྒེའུ་ཁུང་གི་ཁྱད་ནུས་སྒོ་བརྒྱབ་པས། བརྙན་ལེན་མཚམས་བཞག་པ།</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>སྦྱར་རིས།</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>སྤྱིར་ཟླ་བཞིན་གྱི་རླབས་བྱེད་པ་དང་པོ་སྐྱེད་ཞིང་གི་བེད་སྐྱེད་བྱེད་པ་ཡིན།</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>སྦྱར་རིས།</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>གྱི་རླབས་བྱེད་པ་ཡིན།</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>ཕབ་འཇུག་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ་སྐར་ཆ་%1རྗེས་སུ་འགོ་སློང་སྲིད།</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>རོགས་རམ་འཚོལ་བ།</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>མུ་མཐུད་ཡོལ་པར་རྒྱག་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>འགུལ་ཁུལ་གྱི་མཇུག་ངོས་ལ་སླེབས།</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>རིང་ཐུང་རིང་ཤོས་སླེབས་ཟིན།</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>འཛིན་བཟུང་ཁུལ་སྙོམས་སྒྲིག་བྱེད།</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>ཙི་གུའི་འགྲིལ་འཁོར་སྒྲིལ་བའམ་འཛིན་བཟུང་ཁུལ་ལ་གཅིག་རྡེབ་བྱེད།</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>འགྲིལ་འཁོར་སྒྲིལ་ཚད་དལ་རུ་གཏོང་དང་།</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>ནུས་མེད་ཁུལ། __གནོན་རོགས།</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>འདིར་ཡིག་ཆ་སྣོན་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>འགོ་སློང་།/བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>ཕྱིར་འཐེན།/ཉར་བ།</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>ཁུལ་ཁོངས་སྙོམས་སྒྲིག</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་བཀོད།</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>བརྙན་བཤུས་མགྱོགས་མྱུར་འགོ་སློང་བ།</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>འོད་རྟགས་ཡོད་པའི་སྒེའུ་ཁུང་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>སྐར་ཆ་5འགྱངས་ནས་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>བརྙན་ཡོལ་ཡོངས་བཤུ་ལེན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>གྲུ་བཞི་ནར་མོ།</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>འཇོང་དབྱིབས།</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>དྲང་ཕིག</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>པིར་སྨྱུག</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ཡི་གེ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>བདམས་པའི་རི་མོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ནུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>རོགས་པ།</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་གསལ་བ།</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>སྒྲ་འབེབས།</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>མཐེབ་གནོན།</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>བརྙན་མིག </translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>བརྙན་འབེབས་གང་མགྱོགས་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>གདམ་ག</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>བརྙན་འབེབས་དང་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>ཕབ་བཟོའི་ཙི་གུ།</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>ཡོ་བྱད།</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>སྦྱར་རིས།</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>པར་རིས་དབྱེ་འབྱེད་མགྱོགས་མྱུར་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>འགུལ་ནས་བཪྙན་ལེན་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>མདའ་རྟགས།</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>གྲུ་བཞི་ནར་མོ།
Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་ཐུབ།</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>འཇོང་དབྱིབས་
Shiftམནན་ནས་སྒོར་དབྱིབས་འབྲི་ཐུབ། </translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>ཕག་ཏོ་
Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>རབ་རིབ་ཡོད་ཚད་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>ཕག་ཏོ་ཆེ་ཆུང་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>ཡི་གེ་ཆེ་ཆུང་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>མཐེབ་གཅུས་Kམངོན་པ།</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>མཐེབ་གཅུས་ཡིབ་པ་ (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>མཐེབ་གཅུས་མངོན་པ་ (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>བཪྙན་མིག་ཁ་ཕྱེ།(C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>བཪྙན་མིག་ཁ་རྒྱོབ་ (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་བཀོད།</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>སྒྲིག་བཀོད་(F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>རྣམ་བཞག</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>ལྡེབ་གྲངས།</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>སྒྲ་འབེབས།</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>སྐད་དུང་།</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>མ་ལག་སྒྲ་ཟློས།</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>གདམ་ག</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>འོད་རྟགས་གསལ་བ།</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>གནོན་པ་གསལ་བ།</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>བཪྙན་ཟློས།</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>ཕག་ཏོ་ (L)
Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>མདའ་རྩེ་ (X)
Shiftམནན་ནས་ཐད་དཔྱང་དང་ཆུ་སྙོམས་ཀྱི་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>པིར་སྨྱུག་ (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>རབ་རིབ། (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>ཡི་གེ། (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>འགྲིལ་ནས་པར་ལེན་ (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>ཡི་གེ་ངོས་འཛིན་ Alt+O</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>སྦྱར་རིས་ (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>ཕྱིར་འཐེན་ Ctrl+Z</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>པར་རིས།</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>ཉར་སྐབས་གནས་ས་སྒྲིག་འགོད་བྱེད་པ། </translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>རྣམ་བཞག་ </translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>མཐའ་སྒྲོམ་ཕན་ནུས།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མཐའ་སྒྲོམ་མེད་པ།</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>བརྙན་སྟོན།</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>ཕྱིའི་མཐའ་སྒྲོམ།</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>བཟོ་ལྟ།</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>གྲུ་བཞི་ནར་མོ།
Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་ཐུབ།</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>པར་རིས།</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>པར་རིས།</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>ཁ་རྒྱག་(Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>ཁ་རྒྱག་(Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>ཕབ་བཟོ་ཁུལ་ཁོངས་ཀྱི་ཁྱབ་ཁོངས་%1*%2ནང་ཚུན་ལེགས་སྒྲིག་བྱས་ན། བརྙན་འཕྲིན་གྱི་གྲུབ་འབྲས་དེ་བས་ཡག </translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>བརྙན་ཕབ་བྱེད་ནུས་གནས་སྐབས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
</TS>
